@@ -340,6 +340,14 @@ var CreatePipeline = func(client *gitlab.Client, projectID any, opts *gitlab.Cre
 	return pipe, err
 }
 
+var CreateMergeRequestPipeline = func(client *gitlab.Client, projectID interface{}, mr int) (*gitlab.PipelineInfo, error) {
+	if client == nil {
+		client = apiClient.Lab()
+	}
+	pipe, _, err := client.MergeRequests.CreateMergeRequestPipeline(projectID, mr)
+	return pipe, err
+}
+
 var RunPipelineTrigger = func(client *gitlab.Client, projectID any, opts *gitlab.RunPipelineTriggerOptions) (*gitlab.Pipeline, error) {
 	pipe, _, err := client.PipelineTriggers.RunPipelineTrigger(projectID, opts)
 	return pipe, err
