@@ -7,7 +7,7 @@ import (
 	"github.com/spf13/cobra"
 )
 
-func NewCmdDuo(f *cmdutils.Factory) *cobra.Command {
+func NewCmdDuo(f cmdutils.Factory) *cobra.Command {
 	duoCmd := &cobra.Command{
 		Use:   "duo <command> prompt",
 		Short: "Generate terminal commands from natural language.",
