@@ -11,13 +11,15 @@ import (
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 )
 
-type ListOptions struct {
-	Group    string
-	BaseRepo func() (glrepo.Interface, error)
+type options struct {
+	group    string
+	baseRepo func() (glrepo.Interface, error)
 }
 
-func NewDummyCmd(f cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.Command {
-	opts := &ListOptions{}
+func NewDummyCmd(f cmdutils.Factory, runE func(opts *options) error) *cobra.Command {
+	opts := &options{
+		baseRepo: f.BaseRepo,
+	}
 
 	cmd := &cobra.Command{
 		Use:   "list [flags]",
@@ -25,14 +27,9 @@ func NewDummyCmd(f cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.
 		Long:  "List objects",
 		Args:  cobra.ExactArgs(0),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			// support repo override
-			opts.BaseRepo = f.BaseRepo
-
-			group, err := GroupOverride(cmd)
-			if err != nil {
+			if err := opts.complete(cmd); err != nil {
 				return err
 			}
-			opts.Group = group
 
 			if runE != nil {
 				return runE(opts)
@@ -47,7 +44,17 @@ func NewDummyCmd(f cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.
 	return cmd
 }
 
-func runCommand(cli string, runE func(opts *ListOptions) error, doHyperlinks string) error {
+func (o *options) complete(cmd *cobra.Command) error {
+	group, err := GroupOverride(cmd)
+	if err != nil {
+		return err
+	}
+	o.group = group
+
+	return nil
+}
+
+func runCommand(cli string, runE func(opts *options) error, doHyperlinks string) error {
 	factory := &cmdtest.Factory{
 		ConfigStub: func() (config.Config, error) {
 			return config.NewBlankConfig(), nil
@@ -68,15 +75,15 @@ func TestGroupOverride(t *testing.T) {
 	t.Setenv("GITLAB_GROUP", "GROUP/NAME")
 
 	t.Run("List command with GITLAB_GROUP env var and group", func(t *testing.T) {
-		gotOpts := &ListOptions{}
+		gotOpts := &options{}
 
-		err := runCommand("--group GROUP/OVERRIDE", func(opts *ListOptions) error {
+		err := runCommand("--group GROUP/OVERRIDE", func(opts *options) error {
 			gotOpts = opts
 			return nil
 		}, "")
 
 		assert.NoError(t, err)
-		gotGroup := gotOpts.Group
+		gotGroup := gotOpts.group
 		// make sure the GITLAB_GROUP env variable is not used
 		assert.NotEqual(t, gotGroup, "GROUP/NAME")
 		// make sure the group flag was used instead
@@ -84,67 +91,67 @@ func TestGroupOverride(t *testing.T) {
 	})
 
 	t.Run("List command with GITLAB_GROUP env var and no group flag", func(t *testing.T) {
-		gotOpts := &ListOptions{}
+		gotOpts := &options{}
 
-		err := runCommand("", func(opts *ListOptions) error {
+		err := runCommand("", func(opts *options) error {
 			gotOpts = opts
 			return nil
 		}, "")
 
 		assert.NoError(t, err)
-		gotGroup := gotOpts.Group
+		gotGroup := gotOpts.group
 		// make sure the GITLAB_GROUP env variable is used
 		assert.Equal(t, gotGroup, "GROUP/NAME")
 	})
 
 	t.Run("List command with GITLAB_GROUP env var and repo flag", func(t *testing.T) {
-		gotOpts := &ListOptions{}
+		gotOpts := &options{}
 
-		err := runCommand("--repo OWNER2/REPO2", func(opts *ListOptions) error {
+		err := runCommand("--repo OWNER2/REPO2", func(opts *options) error {
 			gotOpts = opts
 			return nil
 		}, "")
 
 		assert.NoError(t, err)
-		gotGroup := gotOpts.Group
+		gotGroup := gotOpts.group
 		// make sure the GITLAB_GROUP env variable is not used
 		assert.Equal(t, gotGroup, "")
 		// make sure the repo option is used instead
-		gotRepo, _ := gotOpts.BaseRepo()
+		gotRepo, _ := gotOpts.baseRepo()
 		assert.Equal(t, gotRepo.FullName(), "OWNER2/REPO2")
 	})
 
 	t.Run("List command with GITLAB_GROUP env var and base repo but no repo flag", func(t *testing.T) {
-		gotOpts := &ListOptions{}
+		gotOpts := &options{}
 
-		err := runCommand("", func(opts *ListOptions) error {
+		err := runCommand("", func(opts *options) error {
 			gotOpts = opts
 			return nil
 		}, "")
 
 		assert.NoError(t, err)
-		gotGroup := gotOpts.Group
+		gotGroup := gotOpts.group
 		// make sure the GITLAB_GROUP env variable is used
 		assert.Equal(t, gotGroup, "GROUP/NAME")
 		// make sure the default baserepo is still used
-		gotRepo, _ := gotOpts.BaseRepo()
+		gotRepo, _ := gotOpts.baseRepo()
 		assert.Equal(t, gotRepo.FullName(), "OWNER/REPO")
 	})
 
 	t.Run("List command with GITLAB_GROUP env var, repo and groups flags", func(t *testing.T) {
-		gotOpts := &ListOptions{}
+		gotOpts := &options{}
 
-		err := runCommand("--repo OWNER2/REPO2 --group GROUP/OVERRIDE", func(opts *ListOptions) error {
+		err := runCommand("--repo OWNER2/REPO2 --group GROUP/OVERRIDE", func(opts *options) error {
 			gotOpts = opts
 			return nil
 		}, "")
 
 		assert.NoError(t, err)
-		gotGroup := gotOpts.Group
+		gotGroup := gotOpts.group
 		// make sure no group option is set at all (group settings ignored)
 		assert.Equal(t, gotGroup, "")
 		// make sure the repo flag is used instead
-		gotRepo, _ := gotOpts.BaseRepo()
+		gotRepo, _ := gotOpts.baseRepo()
 		assert.Equal(t, gotRepo.FullName(), "OWNER2/REPO2")
 	})
 }
