@@ -6,14 +6,14 @@ import (
 	"gitlab.com/gitlab-org/cli/pkg/prompt"
 
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 )
 
 var boardName string
 
-func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
+func NewCmdCreate(f cmdutils.Factory) *cobra.Command {
 	issueCmd := &cobra.Command{
 		Use:     "create [flags]",
 		Short:   `Create a project issue board.`,
@@ -25,8 +25,8 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 				boardName = args[0]
 			}
 			var err error
-			out := f.IO.StdOut
-			c := f.IO.Color()
+			out := f.IO().StdOut
+			c := f.IO().Color()
 
 			apiClient, err := f.HttpClient()
 			if err != nil {
