@@ -1,6 +1,7 @@
 package create
 
 import (
+	"encoding/json"
 	"io"
 	"net/http"
 	"os"
@@ -366,7 +367,7 @@ func TestReleaseCreateWithPublishToCatalog(t *testing.T) {
 	originalWd, err := os.Getwd()
 	require.NoError(t, err)
 
-	err = os.Chdir(filepath.Join(originalWd, "catalog", "testdata", "test-repo"))
+	err = os.Chdir(filepath.Join(originalWd, "..", "..", "project", "publish", "catalog", "testdata", "test-repo"))
 	require.NoError(t, err)
 
 	for _, tc := range tests {
@@ -405,7 +406,7 @@ func TestReleaseCreateWithPublishToCatalog(t *testing.T) {
 
 						assert.JSONEq(t, tc.wantBody, string(body))
 
-						response := httpmock.NewJSONResponse(http.StatusOK, map[string]interface{}{
+						response := httpmock.NewJSONResponse(http.StatusOK, map[string]any{
 							"catalog_url": "https://gitlab.example.com/explore/catalog/my-namespace/my-component-project",
 						})
 
@@ -571,3 +572,109 @@ func TestReleaseCreate_MilestoneClosing(t *testing.T) {
 		})
 	}
 }
+
+func TestReleaseCreate_ExperimentalNotes(t *testing.T) {
+	tests := []struct {
+		name                string
+		cli                 string
+		files               map[string]string
+		wantErr             bool
+		errMsg              string
+		setupHTTPStubs      bool
+		expectedDescription string
+	}{
+		{
+			name:           "when experimental notes is used with notes flag",
+			cli:            `0.0.1 --experimental-notes-text-or-file "test.md" --notes "test"`,
+			wantErr:        true,
+			errMsg:         "if any flags in the group [experimental-notes-text-or-file notes] are set none of the others can be; [experimental-notes-text-or-file notes] were all set",
+			setupHTTPStubs: false,
+		},
+		{
+			name:           "when experimental notes is used with notes-file flag",
+			cli:            `0.0.1 --experimental-notes-text-or-file "test.md" --notes-file "other.md"`,
+			wantErr:        true,
+			errMsg:         "if any flags in the group [experimental-notes-text-or-file notes-file] are set none of the others can be; [experimental-notes-text-or-file notes-file] were all set",
+			setupHTTPStubs: false,
+		},
+		{
+			name: "when experimental notes points to existing file",
+			cli:  `0.0.1 --experimental-notes-text-or-file "test.md"`,
+			files: map[string]string{
+				"test.md": "# Test Release\nThis is a test release.",
+			},
+			setupHTTPStubs:      true,
+			expectedDescription: "# Test Release\nThis is a test release.",
+		},
+		{
+			name:                "when experimental notes has non-existent file and falls back to text",
+			cli:                 `0.0.1 --experimental-notes-text-or-file "This is plain text"`,
+			setupHTTPStubs:      true,
+			expectedDescription: "This is plain text",
+		},
+		{
+			name:                "when experimental notes contains spaces, treats as text",
+			cli:                 `0.0.1 --experimental-notes-text-or-file "This contains spaces.md"`,
+			setupHTTPStubs:      true,
+			expectedDescription: "This contains spaces.md",
+		},
+		{
+			name:                "when experimental notes has leading/trailing spaces",
+			cli:                 `0.0.1 --experimental-notes-text-or-file " notes.md "`,
+			setupHTTPStubs:      true,
+			expectedDescription: " notes.md ",
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			tempDir := t.TempDir()
+			err := os.Chdir(tempDir)
+			require.NoError(t, err)
+
+			for filename, content := range tt.files {
+				err := os.WriteFile(filename, []byte(content), 0o600)
+				require.NoError(t, err)
+			}
+
+			fakeHTTP := &httpmock.Mocker{
+				MatchURL: httpmock.PathAndQuerystring,
+			}
+			defer fakeHTTP.Verify(t)
+
+			if tt.setupHTTPStubs {
+				fakeHTTP.RegisterResponder(http.MethodGet, "/api/v4/projects/OWNER/REPO/releases/0%2E0%2E1",
+					httpmock.NewStringResponse(http.StatusNotFound, `{"message":"404 Not Found"}`))
+
+				fakeHTTP.RegisterResponder(http.MethodPost, "/api/v4/projects/OWNER/REPO/releases",
+					func(req *http.Request) (*http.Response, error) {
+						var reqBody map[string]any
+						err := json.NewDecoder(req.Body).Decode(&reqBody)
+						require.NoError(t, err)
+
+						assert.Equal(t, tt.expectedDescription, reqBody["description"])
+
+						resp, _ := httpmock.NewStringResponse(http.StatusCreated, `{
+							"name": "test_release",
+							"tag_name": "0.0.1",
+							"_links": {
+								"self": "https://gitlab.com/OWNER/REPO/-/releases/0.0.1"
+							}
+						}`)(req)
+						return resp, nil
+					})
+			}
+
+			output, err := runCommand(fakeHTTP, false, tt.cli)
+
+			if tt.wantErr {
+				require.Error(t, err)
+				assert.Equal(t, tt.errMsg, err.Error())
+			} else {
+				require.NoErrorf(t, err, "error running command `create %s`: %v", tt.cli, err)
+				assert.Contains(t, output.Stderr(), "✓ Release created:")
+				assert.Empty(t, output.String())
+			}
+		})
+	}
+}
