@@ -8,31 +8,29 @@ import (
 	"github.com/spf13/cobra"
 	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
-	"gitlab.com/gitlab-org/cli/commands/release/releaseutils/upload"
 	"gitlab.com/gitlab-org/cli/internal/config"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 	"gitlab.com/gitlab-org/cli/pkg/prompt"
 )
 
-type DeleteOpts struct {
-	ForceDelete bool
-	DeleteTag   bool
-	TagName     string
+type options struct {
+	forceDelete bool
+	deleteTag   bool
+	tagName     string
 
-	AssetLinks []*upload.ReleaseAsset
-	AssetFiles []*upload.ReleaseFile
-
-	IO         *iostreams.IOStreams
-	HTTPClient func() (*gitlab.Client, error)
-	BaseRepo   func() (glrepo.Interface, error)
-	Config     func() (config.Config, error)
+	io         *iostreams.IOStreams
+	httpClient func() (*gitlab.Client, error)
+	baseRepo   func() (glrepo.Interface, error)
+	config     func() (config.Config, error)
 }
 
 func NewCmdDelete(f cmdutils.Factory) *cobra.Command {
-	opts := &DeleteOpts{
-		IO:     f.IO(),
-		Config: f.Config,
+	opts := &options{
+		io:         f.IO(),
+		httpClient: f.HttpClient,
+		baseRepo:   f.BaseRepo,
+		config:     f.Config,
 	}
 
 	cmd := &cobra.Command{
@@ -54,44 +52,53 @@ func NewCmdDelete(f cmdutils.Factory) *cobra.Command {
 			$ glab release delete v1.0.1 --with-tag
 		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			opts.HTTPClient = f.HttpClient
-			opts.BaseRepo = f.BaseRepo
+			opts.complete(args)
 
-			opts.TagName = args[0]
-
-			if !opts.ForceDelete && !opts.IO.PromptEnabled() {
-				return &cmdutils.FlagError{Err: fmt.Errorf("--yes or -y flag is required when not running interactively.")}
+			if err := opts.validate(); err != nil {
+				return err
 			}
 
-			return deleteRun(opts)
+			return opts.run()
 		},
 	}
 
-	cmd.Flags().BoolVarP(&opts.ForceDelete, "yes", "y", false, "Skip the confirmation prompt.")
-	cmd.Flags().BoolVarP(&opts.DeleteTag, "with-tag", "t", false, "Delete the associated tag.")
+	cmd.Flags().BoolVarP(&opts.forceDelete, "yes", "y", false, "Skip the confirmation prompt.")
+	cmd.Flags().BoolVarP(&opts.deleteTag, "with-tag", "t", false, "Delete the associated tag.")
 
 	return cmd
 }
 
-func deleteRun(opts *DeleteOpts) error {
-	client, err := opts.HTTPClient()
+func (o *options) complete(args []string) {
+	o.tagName = args[0]
+}
+
+func (o *options) validate() error {
+	if !o.forceDelete && !o.io.PromptEnabled() {
+		return &cmdutils.FlagError{Err: fmt.Errorf("--yes or -y flag is required when not running interactively.")}
+	}
+
+	return nil
+}
+
+func (o *options) run() error {
+	client, err := o.httpClient()
 	if err != nil {
 		return err
 	}
 
-	repo, err := opts.BaseRepo()
+	repo, err := o.baseRepo()
 	if err != nil {
 		return err
 	}
-	color := opts.IO.Color()
+	color := o.io.Color()
 	var resp *gitlab.Response
 
-	opts.IO.Logf("%s Validating tag %s=%s %s=%s\n",
+	o.io.Logf("%s Validating tag %s=%s %s=%s\n",
 		color.ProgressIcon(),
 		color.Blue("repo"), repo.FullName(),
-		color.Blue("tag"), opts.TagName)
+		color.Blue("tag"), o.tagName)
 
-	release, resp, err := client.Releases.GetRelease(repo.FullName(), opts.TagName)
+	release, resp, err := client.Releases.GetRelease(repo.FullName(), o.tagName)
 	if err != nil {
 		if resp != nil && (resp.StatusCode == http.StatusNotFound || resp.StatusCode == http.StatusForbidden) {
 			return cmdutils.WrapError(err, fmt.Sprintf("no release found for %q.", repo.FullName()))
@@ -99,41 +106,41 @@ func deleteRun(opts *DeleteOpts) error {
 		return cmdutils.WrapError(err, "failed to fetch release.")
 	}
 
-	if !opts.ForceDelete && opts.IO.PromptEnabled() {
-		opts.IO.Logf("This action will permanently delete release %q immediately.\n\n", release.TagName)
-		err = prompt.Confirm(&opts.ForceDelete, fmt.Sprintf("Are you ABSOLUTELY SURE you wish to delete this release %q?", release.Name), false)
+	if !o.forceDelete && o.io.PromptEnabled() {
+		o.io.Logf("This action will permanently delete release %q immediately.\n\n", release.TagName)
+		err = prompt.Confirm(&o.forceDelete, fmt.Sprintf("Are you ABSOLUTELY SURE you wish to delete this release %q?", release.Name), false)
 		if err != nil {
 			return cmdutils.WrapError(err, "could not prompt")
 		}
 	}
 
-	if !opts.ForceDelete {
+	if !o.forceDelete {
 		return cmdutils.CancelError()
 	}
 
-	opts.IO.Logf("%s Deleting release %s=%s %s=%s\n",
+	o.io.Logf("%s Deleting release %s=%s %s=%s\n",
 		color.ProgressIcon(),
 		color.Blue("repo"), repo.FullName(),
-		color.Blue("tag"), opts.TagName)
+		color.Blue("tag"), o.tagName)
 
 	release, _, err = client.Releases.DeleteRelease(repo.FullName(), release.TagName)
 	if err != nil {
 		return cmdutils.WrapError(err, "failed to delete release.")
 	}
 
-	opts.IO.Logf(color.Bold("%s Release %q deleted.\n"), color.RedCheck(), release.Name)
+	o.io.Logf(color.Bold("%s Release %q deleted.\n"), color.RedCheck(), release.Name)
 
-	if opts.DeleteTag {
+	if o.deleteTag {
 
-		opts.IO.Logf("%s Deleting associated tag %q.\n",
-			color.ProgressIcon(), opts.TagName)
+		o.io.Logf("%s Deleting associated tag %q.\n",
+			color.ProgressIcon(), o.tagName)
 
 		_, err = client.Tags.DeleteTag(repo.FullName(), release.TagName)
 		if err != nil {
 			return cmdutils.WrapError(err, "failed to delete tag.")
 		}
 
-		opts.IO.Logf(color.Bold("%s Tag %q deleted.\n"), color.RedCheck(), release.Name)
+		o.io.Logf(color.Bold("%s Tag %q deleted.\n"), color.RedCheck(), release.Name)
 	}
 	return nil
 }
