@@ -16,19 +16,21 @@ import (
 	"gitlab.com/gitlab-org/cli/pkg/utils"
 )
 
-type DeleteOpts struct {
-	HTTPClient func() (*gitlab.Client, error)
-	IO         *iostreams.IOStreams
-	BaseRepo   func() (glrepo.Interface, error)
+type options struct {
+	httpClient func() (*gitlab.Client, error)
+	io         *iostreams.IOStreams
+	baseRepo   func() (glrepo.Interface, error)
 
-	KeyID   int
-	PerPage int
-	Page    int
+	keyID   int
+	perPage int
+	page    int
 }
 
-func NewCmdDelete(f cmdutils.Factory, runE func(*DeleteOpts) error) *cobra.Command {
-	opts := &DeleteOpts{
-		IO: f.IO(),
+func NewCmdDelete(f cmdutils.Factory) *cobra.Command {
+	opts := &options{
+		io:         f.IO(),
+		httpClient: f.HttpClient,
+		baseRepo:   f.BaseRepo,
 	}
 	cmd := &cobra.Command{
 		Use:   "delete <key-id>",
@@ -46,67 +48,67 @@ func NewCmdDelete(f cmdutils.Factory, runE func(*DeleteOpts) error) *cobra.Comma
 		),
 		Args: cobra.MaximumNArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			opts.HTTPClient = f.HttpClient
-			opts.BaseRepo = f.BaseRepo
-
-			if len(args) == 0 {
-				keyID, err := keySelectPrompt(opts)
-				if err != nil {
-					return err
-				}
-				opts.KeyID = keyID
+			if err := opts.complete(args); err != nil {
+				return err
 			}
-
-			if len(args) == 1 {
-				opts.KeyID = utils.StringToInt(args[0])
-			}
-
-			if runE != nil {
-				return runE(opts)
-			}
-
-			return deleteRun(opts)
+			return opts.run()
 		},
 	}
 
-	cmd.Flags().IntVarP(&opts.Page, "page", "p", 1, "Page number.")
-	cmd.Flags().IntVarP(&opts.PerPage, "per-page", "P", 30, "Number of items to list per page.")
+	cmd.Flags().IntVarP(&opts.page, "page", "p", 1, "Page number.")
+	cmd.Flags().IntVarP(&opts.perPage, "per-page", "P", 30, "Number of items to list per page.")
 
 	return cmd
 }
 
-func deleteRun(opts *DeleteOpts) error {
-	httpClient, err := opts.HTTPClient()
-	if err != nil {
-		return err
+func (o *options) complete(args []string) error {
+	if len(args) == 0 {
+		keyID, err := keySelectPrompt(o)
+		if err != nil {
+			return err
+		}
+		o.keyID = keyID
 	}
 
-	_, err = httpClient.Users.DeleteSSHKey(opts.KeyID)
-	if err != nil {
-		return cmdutils.WrapError(err, "deleting SSH key.")
-	}
-
-	if opts.IO.IsOutputTTY() {
-		cs := opts.IO.Color()
-		opts.IO.Logf("%s SSH key deleted.\n", cs.GreenCheck())
-	} else {
-		opts.IO.Logf("SSH key deleted.\n")
+	if len(args) == 1 {
+		o.keyID = utils.StringToInt(args[0])
 	}
 
 	return nil
 }
 
-func keySelectPrompt(opts *DeleteOpts) (int, error) {
-	if !opts.IO.PromptEnabled() {
+func (o *options) run() error {
+	httpClient, err := o.httpClient()
+	if err != nil {
+		return err
+	}
+
+	_, err = httpClient.Users.DeleteSSHKey(o.keyID)
+	if err != nil {
+		return cmdutils.WrapError(err, "deleting SSH key.")
+	}
+
+	if o.io.IsOutputTTY() {
+		cs := o.io.Color()
+		o.io.Logf("%s SSH key deleted.\n", cs.GreenCheck())
+	} else {
+		o.io.Logf("SSH key deleted.\n")
+	}
+
+	return nil
+}
+
+func keySelectPrompt(opts *options) (int, error) {
+	if !opts.io.PromptEnabled() {
 		return 0, cmdutils.FlagError{Err: errors.New("the <key-id> argument is required when prompts are disabled.")}
 	}
 
 	sshKeyListOptions := &gitlab.ListSSHKeysOptions{
-		PerPage: opts.PerPage,
-		Page:    opts.Page,
+		PerPage: opts.perPage,
+		Page:    opts.page,
 	}
 
-	httpClient, err := opts.HTTPClient()
+	httpClient, err := opts.httpClient()
 	if err != nil {
 		return 0, err
 	}
@@ -131,7 +133,7 @@ func keySelectPrompt(opts *DeleteOpts) (int, error) {
 			"Select key to delete - Showing %d/%d keys - page %d/%d",
 			len(keys),
 			resp.TotalItems,
-			opts.Page,
+			opts.page,
 			resp.TotalPages,
 		),
 		Options: surveyOpts,
