@@ -6,10 +6,12 @@ import (
 	"testing"
 
 	gitlab "gitlab.com/gitlab-org/api/client-go"
+	gitlabtesting "gitlab.com/gitlab-org/api/client-go/testing"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdtest"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
+	"go.uber.org/mock/gomock"
 
 	"github.com/google/shlex"
 	"github.com/stretchr/testify/assert"
@@ -20,7 +22,7 @@ func Test_NewCmdDelete(t *testing.T) {
 	tests := []struct {
 		name     string
 		cli      string
-		wants    DeleteOpts
+		wants    options
 		stdinTTY bool
 		wantsErr bool
 	}{
@@ -61,6 +63,15 @@ func Test_NewCmdDelete(t *testing.T) {
 			io, _, _, _ := iostreams.Test()
 			f := &cmdtest.Factory{
 				IOStub: io,
+				HttpClientStub: func() (*gitlab.Client, error) {
+					tc := gitlabtesting.NewTestClient(t)
+					tc.MockProjectVariables.EXPECT().RemoveVariable(gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes()
+					tc.MockGroupVariables.EXPECT().RemoveVariable(gomock.Any(), gomock.Any(), gomock.Any()).AnyTimes()
+					return tc.Client, nil
+				},
+				BaseRepoStub: func() (glrepo.Interface, error) {
+					return glrepo.New("OWNER", "REPO"), nil
+				},
 			}
 
 			io.IsInTTY = tt.stdinTTY
@@ -68,10 +79,7 @@ func Test_NewCmdDelete(t *testing.T) {
 			argv, err := shlex.Split(tt.cli)
 			assert.NoError(t, err)
 
-			cmd := NewCmdDelete(f, func(opts *DeleteOpts) error {
-				return nil
-			})
-
+			cmd := NewCmdDelete(f)
 			cmd.SetArgs(argv)
 			cmd.SetIn(&bytes.Buffer{})
 			cmd.SetOut(&bytes.Buffer{})
@@ -115,40 +123,40 @@ func Test_deleteRun(t *testing.T) {
 
 	tests := []struct {
 		name        string
-		opts        DeleteOpts
+		opts        options
 		wantsErr    bool
 		wantsOutput string
 	}{
 		{
 			name: "delete project variable no scope",
-			opts: DeleteOpts{
-				HTTPClient: httpClient,
-				BaseRepo:   baseRepo,
-				Key:        "TEST_VAR",
-				Scope:      "*",
+			opts: options{
+				httpClient: httpClient,
+				baseRepo:   baseRepo,
+				key:        "TEST_VAR",
+				scope:      "*",
 			},
 			wantsErr:    false,
 			wantsOutput: "✓ Deleted variable TEST_VAR with scope * for owner/repo.\n",
 		},
 		{
 			name: "delete project variable with stage scope",
-			opts: DeleteOpts{
-				HTTPClient: httpClient,
-				BaseRepo:   baseRepo,
-				Key:        "TEST_VAR",
-				Scope:      "stage",
+			opts: options{
+				httpClient: httpClient,
+				baseRepo:   baseRepo,
+				key:        "TEST_VAR",
+				scope:      "stage",
 			},
 			wantsErr:    false,
 			wantsOutput: "✓ Deleted variable TEST_VAR with scope stage for owner/repo.\n",
 		},
 		{
 			name: "delete group variable",
-			opts: DeleteOpts{
-				HTTPClient: httpClient,
-				BaseRepo:   baseRepo,
-				Key:        "TEST_VAR",
-				Scope:      "",
-				Group:      "testGroup",
+			opts: options{
+				httpClient: httpClient,
+				baseRepo:   baseRepo,
+				key:        "TEST_VAR",
+				scope:      "",
+				group:      "testGroup",
 			},
 			wantsErr:    false,
 			wantsOutput: "✓ Deleted variable TEST_VAR for group testGroup.\n",
@@ -157,13 +165,13 @@ func Test_deleteRun(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			_, _ = tt.opts.HTTPClient()
+			_, _ = tt.opts.httpClient()
 
 			io, _, stdout, _ := iostreams.Test()
-			tt.opts.IO = io
+			tt.opts.io = io
 			io.IsInTTY = false
 
-			err := deleteRun(&tt.opts)
+			err := tt.opts.run()
 			assert.NoError(t, err)
 			assert.Equal(t, stdout.String(), tt.wantsOutput)
 		})
